@@ -398,6 +398,7 @@ def delete_files(*paths):
 def download_file(url, dirpath=None, filename=None, chunk_size=8192, **kwargs):
     """
     Download a file from url to dirpath.
+    If dirpath is not provided, the file will be downloaded to a temp directory.
     If filename is provided, the file will be named using filename.
     It is possible to pass extra request options (eg. for authentication) using **kwargs.
     """
@@ -798,7 +799,8 @@ def make_dirs_for_file(path):
         return
     assert_not_dir(path)
     dirpath, _ = split_filepath(path)
-    make_dirs(dirpath)
+    if dirpath:
+        make_dirs(dirpath)
 
 
 def move_dir(path, dest, overwrite=False, **kwargs):
